@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2014 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2003-2015 HP Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -360,6 +360,23 @@ def start(language, auto=True, test_depends=False,
                 if not tui.continue_prompt("Please read the installation notes."):
                     sys.exit(0)
 
+        sec_package_name, is_sec_installed = core.security_package_status()
+
+        if sec_package_name:
+            tui.title("SECURITY PACKAGES")
+            log.info("%s is installed. " % sec_package_name)
+            log.info("%s protects the application from external intrusion attempts making the application secure" % sec_package_name )
+            ok, answer = tui.enter_yes_no("\nWould you like to have this installer install the hplip specific policy/profile", default_value='')
+            if not ok:
+                sys.exit(0)
+            elif answer:
+                if sec_package_name == "SELinux":
+                    core.selinux_install()
+                core.security_package = sec_package_name
+            else:
+                pass
+
+
         #
         # PRE-INSTALL COMMANDS
         #
@@ -547,6 +564,20 @@ def start(language, auto=True, test_depends=False,
                 else:
                     log.info("Network connection present.")
 
+            # sec_package_name, is_sec_installed = core.security_package_status()
+
+            # if sec_package_name:
+            #     tui.title("SECURITY PACKAGES")
+            #     log.info("%s is installed. " % sec_package_name)
+            #     log.info("%s protects the application from external intrusion attempts making the application secure" % sec_package_name )
+            #     ok, answer = tui.enter_yes_no("\nWould you like to have this installer install the hplip specific policy/profile")
+            #     if not ok:
+            #         sys.exit(0)
+            #     elif answer:
+            #         core.security_package = sec_package_name
+            #     else:
+            #         pass
+
             #
             # PRE-DEPEND
             #
@@ -720,7 +751,7 @@ def start(language, auto=True, test_depends=False,
 
             if num_req_missing == 0 and core.hplip_present and core.selected_component == 'hplip' and core.distro_version_supported:
                 path = utils.which('hp-uninstall')
-                ok, choice = tui.enter_choice("HPLIP-%s exists, this may conflict with the new one being installed.\nDo you want to ('i'= Remove and Install*, 'o'= Overwrite, 'q'= Quit)?    :"%(prev_hplip_version),['i','o','q'],'i')
+                ok, choice = tui.enter_choice("HPLIP-%s exists, this may conflict with the new one being installed.\nDo you want to ('i'= Remove and Install*, 'q'= Quit)?    :"%(prev_hplip_version),['i','q'],'i')
                 if not ok or choice=='q':
                     log.error("User Exit")
                     sys.exit(0)
